@@ -19,16 +19,30 @@
 import typer
 import airavata_mft_cli.operations as operations
 import airavata_mft_cli.bootstrap as bootstrap
+from airavata_mft_cli.util import exception_handler
 
 app = typer.Typer()
 
 @app.command("ls")
 def list(storage_path):
-  operations.list(storage_path)
+  try:
+    operations.list(storage_path)
+  except Exception as e:
+    exception_handler(e)
 
 @app.command("cp")
 def copy(source, destination):
-  operations.copy(source, destination)
+  try:
+    operations.copy(source, destination)
+  except Exception as e:
+    exception_handler(e)
+
+@app.command("cp-list")
+def copy_list(source_storage_id, dest_storage_id, list_file):
+  try:
+    operations.copy_list(source_storage_id, dest_storage_id, list_file)
+  except Exception as e:
+    exception_handler(e)
 
 @app.command("init")
 def init_mft():
